/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p resourceslinking_interface /usr/src/ports/kf5-kactivities-stats/kf5-kactivities-stats-5.39.0-1.x86_64/src/kactivities-stats-5.39.0/src/common/dbus/org.kde.ActivityManager.ResourcesLinking.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "resourceslinking_interface.h"

/*
 * Implementation of interface class OrgKdeActivityManagerResourcesLinkingInterface
 */

OrgKdeActivityManagerResourcesLinkingInterface::OrgKdeActivityManagerResourcesLinkingInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgKdeActivityManagerResourcesLinkingInterface::~OrgKdeActivityManagerResourcesLinkingInterface()
{
}


#include "resourceslinking_interface.moc"
